diff mbox series

[v1,2/2] scsi: ufs: change ufshcd_comp_devman_upiu() to ufshcd_compose_devman_upiu()

Message ID 20200706091905.12885-3-huobean@gmail.com (mailing list archive)
State Changes Requested
Headers show
Series make UFS dev_cmd more readable | expand

Commit Message

Bean Huo July 6, 2020, 9:19 a.m. UTC
From: Bean Huo <beanhuo@micron.com>

ufshcd_comp_devman_upiu() alwasy make me confuse that it is a request
completion calling function. Change it to ufshcd_compose_devman_upiu().

Signed-off-by: Bean Huo <beanhuo@micron.com>
---
 drivers/scsi/ufs/ufshcd.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

Comments

Avri Altman July 7, 2020, 5:27 a.m. UTC | #1
> 
> From: Bean Huo <beanhuo@micron.com>
> 
> ufshcd_comp_devman_upiu() alwasy make me confuse that it is a request
> completion calling function. Change it to ufshcd_compose_devman_upiu().
> 
> Signed-off-by: Bean Huo <beanhuo@micron.com>
Acked-by: Avri Altman <avri.altman@wdc.com>
diff mbox series

Patch

diff --git a/drivers/scsi/ufs/ufshcd.c b/drivers/scsi/ufs/ufshcd.c
index 173deee37e26..96d830bb900f 100644
--- a/drivers/scsi/ufs/ufshcd.c
+++ b/drivers/scsi/ufs/ufshcd.c
@@ -2368,12 +2368,13 @@  static inline void ufshcd_prepare_utp_nop_upiu(struct ufshcd_lrb *lrbp)
 }
 
 /**
  * ufshcd_comp_devman_upiu - UFS Protocol Information Unit(UPIU)
  *			     for Device Management Purposes
  * @hba: per adapter instance
  * @lrbp: pointer to local reference block
  */
-static int ufshcd_comp_devman_upiu(struct ufs_hba *hba, struct ufshcd_lrb *lrbp)
+static int ufshcd_compose_devman_upiu(struct ufs_hba *hba,
+				      struct ufshcd_lrb *lrbp)
 {
 	u32 upiu_flags;
 	int ret = 0;
@@ -2564,7 +2565,7 @@  static int ufshcd_compose_dev_cmd(struct ufs_hba *hba,
 	lrbp->intr_cmd = true; /* No interrupt aggregation */
 	hba->dev_cmd.type = cmd_type;
 
-	return ufshcd_comp_devman_upiu(hba, lrbp);
+	return ufshcd_compose_devman_upiu(hba, lrbp);
 }
 
 static int
@@ -2368,12 +2368,13 @@  static inline void ufshcd_prepare_utp_nop_upiu(struct ufshcd_lrb *lrbp)
 
 /**
- * ufshcd_comp_devman_upiu - UFS Protocol Information Unit(UPIU)
+ * ufshcd_compose_devman_upiu - UFS Protocol Information Unit(UPIU)
  *			     for Device Management Purposes
  * @hba: per adapter instance